package com.logicbig.example;

import javax.validation.*;
import javax.validation.constraints.Future;
import java.util.Date;
import java.util.Locale;

public class OverrideDefaultKeysExample {
    private static final Validator validator;

    static {
        Locale.setDefault(Locale.US);//Locale.FRANCE
        Configuration<?> config = Validation.byDefaultProvider().configure();
        ValidatorFactory factory = config.buildValidatorFactory();
        validator = factory.getValidator();
        factory.close();
    }

    private static class MyBean {
        @Future
        private Date date;

        public Date getDate () {
            return date;
        }

        public void setDate (Date date) {
            this.date = date;
        }
    }

    public static void main (String[] args) {
        MyBean myBean = new MyBean();
        myBean.setDate(new Date(System.currentTimeMillis() - 100000));
        validator.validate(myBean).stream()
                 .forEach(OverrideDefaultKeysExample::printError);
    }

    private static void printError (
                        ConstraintViolation<MyBean> violation) {
        System.out.println(violation.getMessage());
    }
}