package com.logicbig.example;


import javax.validation.*;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Pattern;
import java.util.Locale;

public class ResourceBundleExample {
    private static final Validator validator;

    static {
        Locale.setDefault(Locale.US);//Locale.FRANCE
        Configuration<?> config = Validation.byDefaultProvider().configure();
        ValidatorFactory factory = config.buildValidatorFactory();
        validator = factory.getValidator();
        factory.close();
    }

    private static class MyBean {
        private String myString;

        @NotNull(message = "{myBean.myString.null.msg}")
        @Pattern(regexp = "\\D+", message = "{myBean.myString.pattern.msg}")
        public String getMyString () {
            return myString;
        }

        public void setMyString (String myString) {
            this.myString = myString;
        }
    }

    public static void main (String[] args) {
        MyBean myBean = new MyBean();
        myBean.setMyString("jackie10");
        validator.validate(myBean).stream().forEach(ResourceBundleExample::printError);
    }

    private static void printError (
                        ConstraintViolation<MyBean> violation) {
        System.out.println(violation.getMessage());
    }
}