package com.logicbig.example;

import javax.validation.*;
import javax.validation.constraints.Size;

public class ValidatedValueExample {
    private static final Validator validator;

    static {
        Configuration<?> config = Validation.byDefaultProvider().configure();
        ValidatorFactory factory = config.buildValidatorFactory();
        validator = factory.getValidator();
        factory.close();
    }

    private static class TestBean {

        @Size(min = 5, message = "The name '${validatedValue}' must be at least {min}" +
                            " characters long. Length found : '${validatedValue.length()}'")
        private String name;

        public String getName () {
            return name;
        }

        public void setName (String name) {
            this.name = name;
        }
    }

    public static void main (String[] args) {
        TestBean testBean = new TestBean();
        testBean.setName("Mike");

        validator.validate(testBean).stream().forEach(ValidatedValueExample::printError);
    }

    private static void printError (
                        ConstraintViolation<TestBean> violation) {

        System.out.println(violation.getMessage());
    }
}